'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = function (lowlight, defaultStyle) {
  return function SyntaxHighlighter(props) {
    var language = props.language,
        children = props.children,
        _props$style = props.style,
        style = _props$style === undefined ? defaultStyle : _props$style,
        _props$customStyle = props.customStyle,
        customStyle = _props$customStyle === undefined ? {} : _props$customStyle,
        _props$codeTagProps = props.codeTagProps,
        codeTagProps = _props$codeTagProps === undefined ? {} : _props$codeTagProps,
        _props$useInlineStyle = props.useInlineStyles,
        useInlineStyles = _props$useInlineStyle === undefined ? true : _props$useInlineStyle,
        _props$showLineNumber = props.showLineNumbers,
        showLineNumbers = _props$showLineNumber === undefined ? false : _props$showLineNumber,
        _props$startingLineNu = props.startingLineNumber,
        startingLineNumber = _props$startingLineNu === undefined ? 1 : _props$startingLineNu,
        lineNumberStyle = props.lineNumberStyle,
        rest = _objectWithoutProperties(props, ['language', 'children', 'style', 'customStyle', 'codeTagProps', 'useInlineStyles', 'showLineNumbers', 'startingLineNumber', 'lineNumberStyle']);

    var codeTree = language ? lowlight.highlight(language, children) : lowlight.highlightAuto(children);
    var defaultPreStyle = style.hljs || { backgroundColor: '#fff' };
    var preProps = useInlineStyles ? Object.assign({}, rest, { style: Object.assign({}, defaultPreStyle, customStyle) }) : Object.assign({}, rest, { className: 'hljs' });
    var lineNumbers = showLineNumbers ? _react2.default.createElement(LineNumbers, {
      style: lineNumberStyle,
      startingLineNumber: startingLineNumber,
      codeString: children
    }) : null;
    return _react2.default.createElement(
      'pre',
      preProps,
      lineNumbers,
      _react2.default.createElement(
        'code',
        codeTagProps,
        codeTree.value.map(function (node, i) {
          return createElement({
            node: node,
            style: style,
            useInlineStyles: useInlineStyles,
            key: 'code-segement' + i
          });
        })
      )
    );
  };
};

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function createStyleObject(classNames, style) {
  return classNames.reduce(function (styleObject, className) {
    return _extends({}, styleObject, style[className]);
  }, {});
}

function createClassNameString(classNames) {
  return classNames.join(' ');
}

function createChildren(style, useInlineStyles) {
  var childrenCount = 0;
  return function (children) {
    childrenCount += 1;
    return children.map(function (child, i) {
      return createElement({
        node: child,
        style: style,
        useInlineStyles: useInlineStyles,
        key: 'code-segment-' + childrenCount + '-' + i
      });
    });
  };
}

function createElement(_ref) {
  var node = _ref.node,
      style = _ref.style,
      useInlineStyles = _ref.useInlineStyles,
      key = _ref.key;
  var properties = node.properties,
      type = node.type,
      tagName = node.tagName,
      value = node.value;

  if (type === 'text') {
    return value;
  } else if (tagName) {
    var TagName = tagName;
    var childrenCreator = createChildren(style, useInlineStyles);
    var props = useInlineStyles ? { style: createStyleObject(properties.className, style) } : { className: createClassNameString(properties.className) };
    var children = childrenCreator(node.children);
    return _react2.default.createElement(
      TagName,
      _extends({ key: key }, props),
      children
    );
  }
}

function getLineNumbers(lines, startingLineNumber) {
  return lines.map(function (_, i) {
    return _react2.default.createElement(
      'span',
      { className: 'react-syntax-highlighter-line-number', key: 'line-' + i },
      i + startingLineNumber + '\n'
    );
  });
}

function LineNumbers(_ref2) {
  var codeString = _ref2.codeString,
      _ref2$style = _ref2.style,
      style = _ref2$style === undefined ? { float: 'left', paddingRight: '10px' } : _ref2$style,
      startingLineNumber = _ref2.startingLineNumber;

  return _react2.default.createElement(
    'code',
    { style: style },
    getLineNumbers(codeString.replace(/\n$/, '').split('\n'), startingLineNumber)
  );
}